summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmobjectselect.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmobjectselect.h')
-rw-r--r--kpovmodeler/pmobjectselect.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kpovmodeler/pmobjectselect.h b/kpovmodeler/pmobjectselect.h
index 46d39d21..c8604eb4 100644
--- a/kpovmodeler/pmobjectselect.h
+++ b/kpovmodeler/pmobjectselect.h
@@ -34,7 +34,7 @@
/**
* TQListBoxItem for @ref PMObject
*/
-class PMListBoxObject : public QListBoxPixmap
+class PMListBoxObject : public TQListBoxPixmap
{
public:
/**
@@ -84,11 +84,12 @@ private:
class PMObjectSelect : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a selection widget with parent and name
*/
- PMObjectSelect( TQWidget* parent = 0, const char* name = 0,
+ PMObjectSelect( TQWidget* tqparent = 0, const char* name = 0,
bool modal = true );
/**
* Deletes the dialog
@@ -112,13 +113,13 @@ public:
* Only objects above the object link are listed.
*/
static int selectObject( PMObject* link, const TQString& t, PMObject* & obj,
- TQWidget* parent = 0 );
+ TQWidget* tqparent = 0 );
static int selectObject( PMObject* link, const TQStringList& t,
- PMObject* & obj, TQWidget* parent = 0 );
+ PMObject* & obj, TQWidget* tqparent = 0 );
static int selectDeclare( PMObject* link, const TQString& declareType,
- PMObject* & obj, TQWidget* parent = 0 );
+ PMObject* & obj, TQWidget* tqparent = 0 );
static int selectDeclare( PMObject* link, const TQStringList& dt,
- PMObject* & obj, TQWidget* parent = 0 );
+ PMObject* & obj, TQWidget* tqparent = 0 );
protected slots:
void slotHighlighted( TQListBoxItem* lbi );
@@ -84,11 +84,12 @@ private:
public:
/**
- * Creates a selection widget with parent and name
+ * Creates a selection widget with tqparent and name
*/